==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/DataLegendStylingColumnEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let DataLegendStylingColumnEventArgsDescription = /*@__PURE__*/ (() => {
    class DataLegendStylingColumnEventArgsDescription extends Description {
        constructor() {
            super();
            this.h = 0;
            this.i = 0;
            this.n = null;
            this.f = 0;
            this.s = null;
            this.r = null;
            this.q = null;
            this.l = null;
            this.o = null;
            this.t = null;
            this.m = null;
            this.p = null;
            this.u = null;
        }
        get_type() {
            return "DataLegendStylingColumnEventArgs";
        }
        get type() {
            return this.get_type();
        }
        get columnIndex() {
            return this.h;
        }
        set columnIndex(a) {
            this.h = a;
            this.e("ColumnIndex");
        }
        get seriesIndex() {
            return this.i;
        }
        set seriesIndex(a) {
            this.i = a;
            this.e("SeriesIndex");
        }
        get seriesTitle() {
            return this.n;
        }
        set seriesTitle(a) {
            this.n = a;
            this.e("SeriesTitle");
        }
        get valueOriginal() {
            return this.f;
        }
        set valueOriginal(a) {
            this.f = a;
            this.e("ValueOriginal");
        }
        get valueMemberPath() {
            return this.s;
        }
        set valueMemberPath(a) {
            this.s = a;
            this.e("ValueMemberPath");
        }
        get valueMemberLabel() {
            return this.r;
        }
        set valueMemberLabel(a) {
            this.r = a;
            this.e("ValueMemberLabel");
        }
        get valueAbbreviation() {
            return this.q;
        }
        set valueAbbreviation(a) {
            this.q = a;
            this.e("ValueAbbreviation");
        }
        get labelText() {
            return this.l;
        }
        set labelText(a) {
            this.l = a;
            this.e("LabelText");
        }
        get unitsText() {
            return this.o;
        }
        set unitsText(a) {
            this.o = a;
            this.e("UnitsText");
        }
        get valueText() {
            return this.t;
        }
        set valueText(a) {
            this.t = a;
            this.e("ValueText");
        }
        get labelTextColor() {
            return this.m;
        }
        set labelTextColor(a) {
            this.m = a;
            this.e("LabelTextColor");
        }
        get unitsTextColor() {
            return this.p;
        }
        set unitsTextColor(a) {
            this.p = a;
            this.e("UnitsTextColor");
        }
        get valueTextColor() {
            return this.u;
        }
        set valueTextColor(a) {
            this.u = a;
            this.e("ValueTextColor");
        }
    }
    DataLegendStylingColumnEventArgsDescription.$t = /*@__PURE__*/ markType(DataLegendStylingColumnEventArgsDescription, 'DataLegendStylingColumnEventArgsDescription', Description.$);
    return DataLegendStylingColumnEventArgsDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/DataLegendStylingColumnEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let DataLegendStylingColumnEventArgsDescription = /*@__PURE__*/ (() => {
    class DataLegendStylingColumnEventArgsDescription extends Description {
        get_type() {
            return "DataLegendStylingColumnEventArgs";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.j = 0;
            this.k = 0;
            this.q = null;
            this.h = 0;
            this.v = null;
            this.u = null;
            this.t = null;
            this.o = null;
            this.r = null;
            this.w = null;
            this.p = null;
            this.s = null;
            this.x = null;
            this.n = null;
        }
        get columnIndex() {
            return this.j;
        }
        set columnIndex(a) {
            this.j = a;
            this.g("ColumnIndex");
        }
        get seriesIndex() {
            return this.k;
        }
        set seriesIndex(a) {
            this.k = a;
            this.g("SeriesIndex");
        }
        get seriesTitle() {
            return this.q;
        }
        set seriesTitle(a) {
            this.q = a;
            this.g("SeriesTitle");
        }
        get valueOriginal() {
            return this.h;
        }
        set valueOriginal(a) {
            this.h = a;
            this.g("ValueOriginal");
        }
        get valueMemberPath() {
            return this.v;
        }
        set valueMemberPath(a) {
            this.v = a;
            this.g("ValueMemberPath");
        }
        get valueMemberLabel() {
            return this.u;
        }
        set valueMemberLabel(a) {
            this.u = a;
            this.g("ValueMemberLabel");
        }
        get valueAbbreviation() {
            return this.t;
        }
        set valueAbbreviation(a) {
            this.t = a;
            this.g("ValueAbbreviation");
        }
        get labelText() {
            return this.o;
        }
        set labelText(a) {
            this.o = a;
            this.g("LabelText");
        }
        get unitsText() {
            return this.r;
        }
        set unitsText(a) {
            this.r = a;
            this.g("UnitsText");
        }
        get valueText() {
            return this.w;
        }
        set valueText(a) {
            this.w = a;
            this.g("ValueText");
        }
        get labelTextColor() {
            return this.p;
        }
        set labelTextColor(a) {
            this.p = a;
            this.g("LabelTextColor");
        }
        get unitsTextColor() {
            return this.s;
        }
        set unitsTextColor(a) {
            this.s = a;
            this.g("UnitsTextColor");
        }
        get valueTextColor() {
            return this.x;
        }
        set valueTextColor(a) {
            this.x = a;
            this.g("ValueTextColor");
        }
        get groupName() {
            return this.n;
        }
        set groupName(a) {
            this.n = a;
            this.g("GroupName");
        }
    }
    DataLegendStylingColumnEventArgsDescription.$t = /*@__PURE__*/ markType(DataLegendStylingColumnEventArgsDescription, 'DataLegendStylingColumnEventArgsDescription', Description.$);
    return DataLegendStylingColumnEventArgsDescription;
})();
